#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-B5ROm7XuCi7WH2iMCEwo5
key:                  coinbase-pro-0.9.3.2-B5ROm7XuCi7WH2iMCEwo5
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  757a49bc9f84d8257e40c6d951761489
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-B5ROm7XuCi7WH2iMCEwo5
depends:
    HsOpenSSL-0.11.7.9-Ki4UCnirEIQ7d088M0P7Wy
    aeson-2.2.1.0-5Fs1RaTLSq5BR7MHVVBomI
    aeson-casing-0.2.0.0-5QMLpRFQdYEFJZIWmRDakv
    async-2.2.5-H7c59317Mex2thAVLk9lLr base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-1O2DgO6ll1a42YQ8T6nm2W exceptions-0.10.7
    http-api-data-0.6.1-CDlIF7piCclbOx4UUWXN7
    http-client-0.7.19-x3ldo2gsR6CFixZQXOBK9
    http-client-tls-0.3.6.4-CShAYDI2Ur8IjmbOL49Cy4
    http-streams-0.8.9.9-2dQdzUjR62uDvpl2gwLuTN
    http-types-0.12.4-LKu5OHbJ0niIq3wOYqZPSj
    io-streams-1.5.2.2-2kMXjyho5I8AlgyeDMTq3A
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-4OYqhi3GpTpApCIFJRYTKN
    servant-0.20.3.0-HdQB9ySuuHX8ECO1JmBsbd
    servant-client-0.20.3.0-Au486xUKBe9IBh9KB4hGba
    servant-client-core-0.20.3.0-znPXA3Dqyr5sSHd41VeoX
    tasty-1.5.2-G8qbDYbDdvV8pMT2pB4phs
    tasty-hunit-0.10.2-KqamnDdjSCFGEpPHVv7XY4 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-HASZsRsoWS6KLcVAbzXONB
    unordered-containers-0.2.20.1-KjVwmKBzsCnE6cNwSXaI5c
    uuid-1.3.16-AGFlUiV1obhI9fGx4AagUe
    vector-0.13.2.0-4h5s991j4Tv2xGOb8nYid2
    websockets-0.12.7.3-FQRcYD78LrnEs4XuUHywq8
    wuss-2.0.1.6-aZ1ATlhFYSBrf4iPgP2Cx

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

